turbofeeds.widgets.FeedLinksDesc.template_c

Package turbofeeds :: Module widgets :: Class FeedLinksDesc :: Class template_c |
[hide private]

# Class template_c

          object --+
                   |
    kid.BaseTemplate --+
                       |
                      turbofeeds.widgets.FeedLinksDesc.template_c

Instance Methods | [hide private]
_pull(self) Generate events for this template. |
initialize(self) |
Inherited from `kid.BaseTemplate`: `__init__`, `__iter__`, `__str__`, `__unicode__`, `content`, `defined`, `generate`, `pull`, `serialize`, `transform`, `value_of`, `write` Inherited from `kid.BaseTemplate` (private): `_get_assume_encoding`, `_get_match_templates`, `_get_serializer` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| _match_templates = ``[``]``
Inherited from `kid.BaseTemplate`: `serializer`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _pull(self) |
Generate events for this template. Compiled templates implement this method. Overrides: kid.BaseTemplate._pull (inherited documentation)

### initialize(self) |
Overrides: kid.BaseTemplate.initialize